@@ -86,7 +86,7 @@
 #define KCMUTILS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILS_NO_DEPRECATED
-#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KCMUTILS_NO_DEPRECATED_WARNINGS
 #  define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILS_DEPRECATED_WARNINGS_SINCE KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -216,7 +216,7 @@
 #define KCMUTILS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILS_NO_DEPRECATED
-#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KCMUTILS_NO_DEPRECATED_WARNINGS
 #  define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0
@@ -226,7 +226,7 @@
 #  ifdef KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILS_DEPRECATED_WARNINGS_SINCE KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
